@@ -18,7 +18,10 @@ class UnresolvedClassAttribute(NotImplementedError):
 
 
 def resolve_class_attr(
-    cls: type, name: str, argument: object | None, required: bool = True
+    cls: type,
+    name: str,
+    argument: object | None,
+    required: bool = True,
 ) -> None:
     argument = getattr(cls, name, None) if argument is None else argument
     if argument is not None:
@@ -121,3 +124,7 @@ def is_subtype(a: BoundType, b: BoundType) -> bool:  # noqa: C901
         return any(issubclass(a_part, b) for a_part in a)
     assert isinstance(a, type)
     return issubclass(a, b)
+
+
+def fully_qualified_name(cls: type) -> str:
+    return f"{cls.__module__}.{cls.__qualname__}"
